@@ -22,6 +22,9 @@ import os
 import sys
 import json
 import logging
+import cProfile
+import pstats
+from pstats import SortKey
 from datetime import datetime
 from packaging.version import Version as V
 
@@ -32,6 +35,8 @@ from gi.repository import Soup
 from gajim.common import app
 from gajim.common import ged
 from gajim.common import configpaths
+from gajim.common import logging_helpers
+from gajim.common.dbus import logind
 from gajim.common.events import AccountDisonnected
 from gajim.common.events import AllowGajimUpdateCheck
 from gajim.common.events import GajimUpdateAvailable
@@ -46,6 +51,9 @@ from gajim.common.storage.archive import MessageArchiveStorage
 
 
 class CoreApplication:
+    def __init__(self) -> None:
+        self._profiling_session = None
+
     def _init_core(self) -> None:
         # Create and initialize Application Paths & Databases
         app.app = self
@@ -80,6 +88,8 @@ class CoreApplication:
 
         if sys.platform in ('win32', 'darwin'):
             GLib.timeout_add_seconds(20, self._check_for_updates)
+        else:
+            logind.enable()
 
         for account in app.settings.get_active_accounts():
             app.connections[account] = Client(account)
@@ -88,6 +98,53 @@ class CoreApplication:
     def _log(self) -> logging.Logger:
         return app.log('gajim.application')
 
+    def _core_command_line(self, options: GLib.VariantDict) -> None:
+        if options.contains('cprofile'):
+            self.start_profiling()
+
+        if options.contains('gdebug'):
+            os.environ['G_MESSAGES_DEBUG'] = 'all'
+
+        if options.contains('separate'):
+            configpaths.set_separation(True)
+
+        config_path = options.lookup_value('config-path')
+        if config_path is not None:
+            config_path = config_path.get_string()
+            configpaths.set_config_root(config_path)
+
+        configpaths.init()
+        logging_helpers.init()
+
+        if options.contains('quiet'):
+            logging_helpers.set_quiet()
+
+        if options.contains('verbose'):
+            logging_helpers.set_verbose()
+
+        loglevel = options.lookup_value('loglevel')
+        if loglevel is not None:
+            loglevel = loglevel.get_string()
+            logging_helpers.set_loglevels(loglevel)
+
+        if options.contains('warnings'):
+            self._show_warnings()
+
+    def start_profiling(self) -> None:
+        self._log.info('Start profiling')
+        self._profiling_session = cProfile.Profile()
+        self._profiling_session.enable()
+
+    def end_profiling(self) -> None:
+        if self._profiling_session is None:
+            return
+
+        self._profiling_session.disable()
+        self._log.info('End profiling')
+        ps = pstats.Stats(self._profiling_session)
+        ps = ps.sort_stats(SortKey.CUMULATIVE)
+        ps.print_stats()
+
     def start_shutdown(self, *args: Any, **kwargs: Any) -> None:
         app.app.systray.shutdown()
 
@@ -116,8 +173,11 @@ class CoreApplication:
 
     def _shutdown_core(self) -> None:
         # Commit any outstanding SQL transactions
+        app.storage.archive.cleanup_chat_history()
         app.storage.cache.shutdown()
         app.storage.archive.shutdown()
+        self.end_profiling()
+        logind.shutdown()
 
     def _quit_app(self) -> None:
         self._shutdown_core()
