@@ -16,7 +16,7 @@
 Handles Jingle sessions (XEP 0166)
 """
 
-#TODO:
+# TODO:
 # * 'senders' attribute of 'content' element
 # * security preconditions
 # * actions:
@@ -29,7 +29,10 @@ Handles Jingle sessions (XEP 0166)
 
 from __future__ import annotations
 
+from typing import Any
+from typing import Callable
 from typing import Optional
+from typing import TYPE_CHECKING
 
 import time
 import logging
@@ -38,6 +41,7 @@ from enum import Enum, unique
 import nbxmpp
 from nbxmpp import JID
 from nbxmpp.namespaces import Namespace
+from nbxmpp.protocol import Iq
 from nbxmpp.util import generate_id
 
 from gajim.common import app
@@ -52,6 +56,8 @@ from gajim.common.jingle_content import JingleContent
 from gajim.common.jingle_content import JingleContentSetupException
 from gajim.common.jingle_ft import State
 from gajim.common.file_props import FilesProp
+if TYPE_CHECKING:
+    from gajim.common.jingle_transport import JingleTransport
 
 
 log = logging.getLogger("app.c.jingle_session")
@@ -65,6 +71,7 @@ JINGLE_EVENTS = {
     'jingle-error-received': events.JingleErrorReceived
 }
 
+
 # FIXME: Move it to JingleSession.States?
 @unique
 class JingleStates(Enum):
@@ -75,24 +82,28 @@ class JingleStates(Enum):
     PENDING = 1
     ACTIVE = 2
 
+
 class OutOfOrder(Exception):
     """
     Exception that should be raised when an action is received when in the wrong
     state
     """
 
+
 class TieBreak(Exception):
     """
     Exception that should be raised in case of a tie, when we overrule the other
     action
     """
 
+
 class FailedApplication(Exception):
     """
     Exception that should be raised in case responder supports none of the
     payload-types offered by the initiator
     """
 
+
 class JingleSession:
     """
     This represents one jingle session, that is, one or more content types
@@ -114,10 +125,10 @@ class JingleSession:
         """
         # negotiated contents
         self.contents: dict[tuple[str, str], JingleContent] = {}
-        self.connection = con # connection to use
+        self.connection = con  # connection to use
         # our full jid
         self.ourjid = str(self.connection.get_own_jid())
-        self.peerjid = jid # jid we connect to
+        self.peerjid = jid  # jid we connect to
         # jid we use as the initiator
         self.initiator = self.ourjid if weinitiate else self.peerjid
         # jid we use as the responder
@@ -131,61 +142,64 @@ class JingleSession:
         self.state = JingleStates.ENDED
         if not sid:
             sid = generate_id()
-        self.sid = sid # sessionid
+        self.sid = sid  # sessionid
         # iq stanza id, used to determine which sessions to summon callback
         # later on when iq-result stanza arrives
         if iq_id is not None:
             self.iq_ids = [iq_id]
         else:
             self.iq_ids = []
-        self.accepted = True # is this session accepted by user
+        self.accepted = True  # is this session accepted by user
         # Tells whether this session is a file transfer or not
         self.session_type_ft = False
         # callbacks to call on proper contents
         # use .prepend() to add new callbacks, especially when you're going
         # to send error instead of ack
-        self.callbacks = {
-            'content-accept':       [self.__ack, self.__on_content_accept,
-                                     self.__broadcast],
-            'content-add':          [self.__ack,
-                                     self.__on_content_add, self.__broadcast
-                                    ], #TODO
-            'content-modify':       [self.__ack], #TODO
-            'content-reject':       [self.__ack, self.__on_content_remove],
-            'content-remove':       [self.__ack, self.__on_content_remove],
-            'description-info':     [self.__ack, self.__broadcast], #TODO
-            'security-info':        [self.__ack], #TODO
-            'session-accept':       [self.__ack, self.__on_session_accept,
-                                     self.__on_content_accept,
-                                     self.__broadcast],
-            'session-info':         [self.__ack, self.__broadcast,
-                                     self.__on_session_info],
-            'session-initiate':     [self.__ack, self.__on_session_initiate,
-                                     self.__broadcast],
-            'session-terminate':    [self.__ack, self.__on_session_terminate,
-                                     self.__broadcast_all],
-            'transport-info':       [self.__ack, self.__broadcast],
-            'transport-replace':    [self.__ack, self.__broadcast,
-                                     self.__on_transport_replace], #TODO
-            'transport-accept':     [self.__ack, self.__on_session_accept,
-                                     self.__on_content_accept,
-                                     self.__broadcast],
-            'transport-reject':     [self.__ack], #TODO
-            'iq-result':            [self.__broadcast],
-            'iq-error':             [self.__on_error],
+        self.callbacks: dict[str, list[Callable[
+            [nbxmpp.Node, nbxmpp.Node, Optional[nbxmpp.Node], str],
+            None]]] = {
+            'content-accept': [self.__ack,
+                               self.__on_content_accept,
+                               self.__broadcast],
+            'content-add': [self.__ack,
+                            self.__on_content_add,
+                            self.__broadcast],  # TODO
+            'content-modify': [self.__ack],  # TODO
+            'content-reject': [self.__ack, self.__on_content_remove],
+            'content-remove': [self.__ack, self.__on_content_remove],
+            'description-info': [self.__ack, self.__broadcast],  # TODO
+            'security-info': [self.__ack],  # TODO
+            'session-accept': [self.__ack, self.__on_session_accept,
+                               self.__on_content_accept,
+                               self.__broadcast],
+            'session-info': [self.__ack, self.__broadcast,
+                             self.__on_session_info],
+            'session-initiate': [self.__ack, self.__on_session_initiate,
+                                 self.__broadcast],
+            'session-terminate': [self.__ack, self.__on_session_terminate,
+                                  self.__broadcast_all],
+            'transport-info': [self.__ack, self.__broadcast],
+            'transport-replace': [self.__ack, self.__broadcast,
+                                  self.__on_transport_replace],  # TODO
+            'transport-accept': [self.__ack, self.__on_session_accept,
+                                 self.__on_content_accept,
+                                 self.__broadcast],
+            'transport-reject': [self.__ack],  # TODO
+            'iq-result': [self.__broadcast],
+            'iq-error': [self.__on_error],
         }
 
-    def collect_iq_id(self, iq_id):
+    def collect_iq_id(self, iq_id: str) -> None:
         if iq_id is not None:
             self.iq_ids.append(iq_id)
 
-    def approve_session(self):
+    def approve_session(self) -> None:
         """
         Called when user accepts session in UI (when we aren't the initiator)
         """
         self.accept_session()
 
-    def decline_session(self):
+    def decline_session(self) -> None:
         """
         Called when user declines session in UI (when we aren't the initiator)
         """
@@ -193,7 +207,7 @@ class JingleSession:
         reason.addChild('decline')
         self._session_terminate(reason)
 
-    def cancel_session(self):
+    def cancel_session(self) -> None:
         """
         Called when user declines session in UI (when we aren't the initiator)
         """
@@ -215,7 +229,7 @@ class JingleSession:
             content.destroy()
             self.on_session_state_changed()
 
-    def end_session(self):
+    def end_session(self) -> None:
         """
         Called when user stops or cancel session in UI
         """
@@ -250,11 +264,11 @@ class JingleSession:
         Creator must be one of ('we', 'peer', 'initiator', 'responder')
         """
         assert creator in ('we', 'peer', 'initiator', 'responder')
-        if (creator == 'we' and self.weinitiate) or (creator == 'peer' and \
-        not self.weinitiate):
+        if ((creator == 'we' and self.weinitiate) or
+                (creator == 'peer' and not self.weinitiate)):
             creator = 'initiator'
-        elif (creator == 'peer' and self.weinitiate) or (creator == 'we' and \
-        not self.weinitiate):
+        elif ((creator == 'peer' and self.weinitiate) or
+                (creator == 'we' and not self.weinitiate)):
             creator = 'responder'
         content.creator = creator
         content.name = name
@@ -263,7 +277,11 @@ class JingleSession:
             # The content is from us, accept it
             content.accepted = True
 
-    def remove_content(self, creator, name, reason=None):
+    def remove_content(self,
+                       creator: str,
+                       name: str,
+                       reason: Optional[nbxmpp.Node] = None
+                       ) -> None:
         """
         Remove the content `name` created by `creator`
         by sending content-remove, or by sending session-terminate if
@@ -276,7 +294,11 @@ class JingleSession:
         if not self.contents:
             self.end_session()
 
-    def modify_content(self, creator, name, transport=None):
+    def modify_content(self,
+                       creator: str,
+                       name: str,
+                       transport: Optional[JingleTransport] = None
+                       ) -> None:
         '''
         Currently used for transport replacement
         '''
@@ -293,14 +315,16 @@ class JingleSession:
                                  content: Optional[JingleContent] = None
                                  ) -> None:
         if self.state == JingleStates.ENDED:
-            # Session not yet started, only one action possible: session-initiate
+            # Session not yet started, only one action possible:
+            # session-initiate
             if self.is_ready() and self.weinitiate:
                 self.__session_initiate()
         elif self.state == JingleStates.PENDING:
             # We can either send a session-accept or a content-add
             if self.is_ready() and not self.weinitiate:
                 self.__session_accept()
-            elif content and (content.creator == 'initiator') == self.weinitiate:
+            elif (content and
+                  (content.creator == 'initiator') == self.weinitiate):
                 self.__content_add(content)
             elif content and self.weinitiate:
                 self.__content_accept(content)
@@ -309,8 +333,8 @@ class JingleSession:
             # we are sending a file we can only use session_initiate.
             if not content:
                 return
-            we_created_content = (content.creator == 'initiator') \
-                                 == self.weinitiate
+            is_initiator = content.creator == 'initiator'
+            we_created_content = is_initiator == self.weinitiate
             if we_created_content and content.media == 'file':
                 self.__session_initiate()
             if we_created_content:
@@ -320,53 +344,53 @@ class JingleSession:
                 # The other side created this content, we accept it.
                 self.__content_accept(content)
 
-    def is_ready(self):
+    def is_ready(self) -> bool:
         """
         Return True when all codecs and candidates are ready (for all contents)
         """
-        return (all((content.is_ready() for content in self.contents.values()))
-                and self.accepted)
+        ready = [content.is_ready() for content in self.contents.values()]
+        return all(ready) and self.accepted
 
-    def accept_session(self):
+    def accept_session(self) -> None:
         """
         Mark the session as accepted
         """
         self.accepted = True
         self.on_session_state_changed()
 
-    def start_session(self):
+    def start_session(self) -> None:
         """
         Mark the session as ready to be started
         """
         self.accepted = True
         self.on_session_state_changed()
 
-    def send_session_info(self):
+    def send_session_info(self) -> Any:
         pass
 
-    def send_content_accept(self, content):
+    def send_content_accept(self, content: nbxmpp.Node) -> None:
         assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('content-accept')
         jingle.addChild(node=content)
         self.connection.connection.send(stanza)
 
-    def send_transport_info(self, content):
+    def send_transport_info(self, content: nbxmpp.Node) -> None:
         assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('transport-info')
         jingle.addChild(node=content)
         self.connection.connection.send(stanza)
         self.collect_iq_id(stanza.getID())
 
-    def send_description_info(self, content):
+    def send_description_info(self, content: nbxmpp.Node) -> None:
         assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('description-info')
         jingle.addChild(node=content)
         self.connection.connection.send(stanza)
 
-    def on_stanza(self, stanza):
+    def on_stanza(self, stanza: nbxmpp.Node) -> None:
         """
-        A callback for ConnectionJingle. It gets stanza, then tries to send it to
-        all internally registered callbacks. First one to raise
+        A callback for ConnectionJingle. It gets stanza, then tries to send
+        it to all internally registered callbacks. First one to raise
         nbxmpp.NodeProcessed breaks function
         """
         jingle = stanza.getTag('jingle')
@@ -404,7 +428,12 @@ class JingleSession:
             reason.addChild('failed-application')
             self._session_terminate(reason)
 
-    def __ack(self, stanza, jingle, error, action):
+    def __ack(self,
+              stanza: nbxmpp.Node,
+              jingle: nbxmpp.Node,
+              error: Optional[nbxmpp.Node],
+              action: str
+              ) -> None:
         """
         Default callback for action stanzas -- simple ack and stop processing
         """
@@ -412,7 +441,12 @@ class JingleSession:
         response.delChild(response.getQuery())
         self.connection.connection.send(response)
 
-    def __on_error(self, stanza, jingle, error, action):
+    def __on_error(self,
+                   stanza: nbxmpp.Node,
+                   jingle: nbxmpp.Node,
+                   error: nbxmpp.Node,
+                   action: str
+                   ) -> None:
         # FIXME
         text = error.getTagData('text')
         error_name = None
@@ -424,7 +458,7 @@ class JingleSession:
                 error_name = child.getName()
         self.__dispatch_error(error_name, text, error.getAttr('type'))
 
-    def transport_replace(self):
+    def transport_replace(self) -> None:
         transport = JingleTransportIBB()
         # For debug only, delete this and replace for a function
         # that will identify contents by its sid
@@ -438,12 +472,17 @@ class JingleSession:
         self.connection.connection.send(stanza)
         self.state = JingleStates.PENDING
 
-    def __on_transport_replace(self, stanza, jingle, error, action):
+    def __on_transport_replace(self,
+                               stanza: nbxmpp.Node,
+                               jingle: nbxmpp.Node,
+                               error: Optional[nbxmpp.Node],
+                               action: str
+                               ) -> None:
         for content in jingle.iterTags('content'):
             creator = content['creator']
             name = content['name']
+            transport_ns = content.getTag('transport').getNamespace()
             if (creator, name) in self.contents:
-                transport_ns = content.getTag('transport').getNamespace()
                 if transport_ns == Namespace.JINGLE_ICE_UDP:
                     # FIXME: We don't manage anything else than ICE-UDP now...
                     # What was the previous transport?!?
@@ -454,13 +493,15 @@ class JingleSession:
                         'transport'))
                     self.modify_content(creator, name, transport)
                     self.state = JingleStates.PENDING
-                    self.contents[(creator, name)].state = State.TRANSPORT_REPLACE
+                    self.contents[(creator, name)].state = \
+                        State.TRANSPORT_REPLACE
                     self.__ack(stanza, jingle, error, action)
                     self.__transport_accept(transport)
                 else:
                     stanza, jingle = self.__make_jingle('transport-reject')
-                    content = jingle.setTag('content', attrs={'creator': creator,
-                                                              'name': name})
+                    content = jingle.setTag('content',
+                                            attrs={'creator': creator,
+                                                   'name': name})
                     content.setTag('transport', namespace=transport_ns)
                     self.connection.connection.send(stanza)
                     raise nbxmpp.NodeProcessed
@@ -474,7 +515,12 @@ class JingleSession:
                 self.connection.connection.send(stanza)
                 raise nbxmpp.NodeProcessed
 
-    def __on_session_info(self, stanza, jingle, error, action):
+    def __on_session_info(self,
+                          stanza: nbxmpp.Node,
+                          jingle: nbxmpp.Node,
+                          error: Optional[nbxmpp.Node],
+                          action: str
+                          ) -> None:
         # TODO: active, (un)hold, (un)mute
         ringing = jingle.getTag('ringing')
         if ringing is not None:
@@ -484,8 +530,9 @@ class JingleSession:
             raise OutOfOrder
         for child in jingle.getChildren():
             if child.getName() == 'checksum':
-                hash_ = child.getTag('file').getTag(name='hash',
-                                                    namespace=Namespace.HASHES_2)
+                hash_ = child.getTag('file').getTag(
+                    name='hash',
+                    namespace=Namespace.HASHES_2)
                 if hash_ is None:
                     continue
                 algo = hash_.getAttr('algo')
@@ -499,7 +546,12 @@ class JingleSession:
                           type_='modify')
         raise nbxmpp.NodeProcessed
 
-    def __on_content_remove(self, stanza, jingle, error, action):
+    def __on_content_remove(self,
+                            stanza: nbxmpp.Node,
+                            jingle: nbxmpp.Node,
+                            error: Optional[nbxmpp.Node],
+                            action: str
+                            ) -> None:
         for content in jingle.iterTags('content'):
             creator = content['creator']
             name = content['name']
@@ -515,14 +567,23 @@ class JingleSession:
             reason.setTag('success')
             self._session_terminate(reason)
 
-    def __on_session_accept(self, stanza, jingle, error, action):
+    def __on_session_accept(self,
+                            stanza: nbxmpp.Node,
+                            jingle: nbxmpp.Node,
+                            error: Optional[nbxmpp.Node],
+                            action: str
+                            ) -> None:
         # FIXME
         if self.state != JingleStates.PENDING:
             raise OutOfOrder
         self.state = JingleStates.ACTIVE
 
     @staticmethod
-    def __on_content_accept(stanza, jingle, error, action):
+    def __on_content_accept(stanza: nbxmpp.Node,
+                            jingle: nbxmpp.Node,
+                            error: Optional[nbxmpp.Node],
+                            action: str
+                            ) -> None:
         """
         Called when we get content-accept stanza or equivalent one (like
         session-accept)
@@ -533,7 +594,12 @@ class JingleSession:
         #     name = content['name']
         return
 
-    def __on_content_add(self, stanza, jingle, error, action):
+    def __on_content_add(self,
+                         stanza: nbxmpp.Node,
+                         jingle: nbxmpp.Node,
+                         error: Optional[nbxmpp.Node],
+                         action: str
+                         ) -> None:
         if self.state == JingleStates.ENDED:
             raise OutOfOrder
         parse_result = self.__parse_contents(jingle)
@@ -546,7 +612,12 @@ class JingleSession:
         #     self.contents[(content.creator, content.name)].destroy()
         self._raise_event('jingle-request-received', contents=contents)
 
-    def __on_session_initiate(self, stanza, jingle, error, action):
+    def __on_session_initiate(self,
+                              stanza: nbxmpp.Node,
+                              jingle: nbxmpp.Node,
+                              error: Optional[nbxmpp.Node],
+                              action: str
+                              ) -> None:
         """
         We got a jingle session request from other entity, therefore we are the
         receiver... Unpack the data, inform the user
@@ -569,8 +640,8 @@ class JingleSession:
         self.accepted = False   # user did not accept this session yet
         # TODO: If the initiator is unknown to the receiver (e.g., via presence
         # subscription) and the receiver has a policy of not communicating via
-        # Jingle with unknown entities, it SHOULD return a <service-unavailable/>
-        # error.
+        # Jingle with unknown entities, it SHOULD return a
+        # <service-unavailable/> error.
         # Lets check what kind of jingle session does the peer want
         contents, _contents_rejected, reason_txt = self.__parse_contents(jingle)
 
@@ -586,7 +657,8 @@ class JingleSession:
         # If we are not receiving a file
         # Check if there's already a session with this user:
         if contents[0].media != 'file':
-            for session in self.connection.get_module('Jingle').get_jingle_sessions(self.peerjid):
+            jingle_module = self.connection.get_module('Jingle')
+            for session in jingle_module.get_jingle_sessions(self.peerjid):
                 if session is not self:
                     reason = nbxmpp.Node('reason')
                     alternative_session = reason.setTag('alternative-session')
@@ -608,8 +680,8 @@ class JingleSession:
                 file_info = self.connection.get_module('Jingle').get_file_info(
                     pjid, hash_data, n, self.connection.name)
                 if not file_info:
-                    log.warning('The peer %s is requesting a ' \
-                                'file that we don’t have or ' \
+                    log.warning('The peer %s is requesting a '
+                                'file that we don’t have or '
                                 'it is not allowed to request', pjid)
                     self.decline_session()
                     raise nbxmpp.NodeProcessed
@@ -619,7 +691,7 @@ class JingleSession:
         self._raise_event('jingle-request-received', contents=contents)
 
         # Check if it's an A/V call and add it to the archive
-        content_types = []
+        content_types: list[str] = []
         for item in contents:
             content_types.append(item.media)
         if not any(item in ('audio', 'video') for item in content_types):
@@ -637,11 +709,16 @@ class JingleSession:
             KindConstant.CALL_INCOMING,
             additional_data=additional_data)
 
-    def __broadcast(self, stanza, jingle, error, action):
+    def __broadcast(self,
+                    stanza: nbxmpp.Node,
+                    jingle: nbxmpp.Node,
+                    error: Optional[nbxmpp.Node],
+                    action: str
+                    ) -> None:
         """
         Broadcast the stanza contents to proper content handlers
         """
-        #if jingle is None: # it is a iq-result stanza
+        # if jingle is None: # it is a iq-result stanza
         #    for cn in self.contents.values():
         #        cn.on_stanza(stanza, None, error, action)
         #    return
@@ -654,14 +731,23 @@ class JingleSession:
             name = content['name']
             creator = content['creator']
             if (creator, name) not in self.contents:
-                text = 'Content %s (created by %s) does not exist' % (name, creator)
-                self.__send_error(stanza, 'bad-request', text=text, type_='modify')
+                text = 'Content %s (created by %s) does not exist' % (name,
+                                                                      creator)
+                self.__send_error(stanza,
+                                  'bad-request',
+                                  text=text,
+                                  type_='modify')
                 raise nbxmpp.NodeProcessed
 
             cn = self.contents[(creator, name)]
             cn.on_stanza(stanza, content, error, action)
 
-    def __on_session_terminate(self, stanza, jingle, error, action):
+    def __on_session_terminate(self,
+                               stanza: nbxmpp.Node,
+                               jingle: nbxmpp.Node,
+                               error: Optional[nbxmpp.Node],
+                               action: str
+                               ) -> None:
         self.connection.get_module('Jingle').delete_jingle_session(self.sid)
         reason, text = self.__reason_from_stanza(jingle)
         if reason not in ('success', 'cancel', 'decline'):
@@ -684,18 +770,28 @@ class JingleSession:
                               media=None,
                               reason=text)
 
-    def __broadcast_all(self, stanza, jingle, error, action):
+    def __broadcast_all(self,
+                        stanza: nbxmpp.Node,
+                        jingle: nbxmpp.Node,
+                        error: Optional[nbxmpp.Node],
+                        action: str
+                        ) -> None:
         """
         Broadcast the stanza to all content handlers
         """
         for content in self.contents.values():
             content.on_stanza(stanza, None, error, action)
 
-    def __parse_contents(self, jingle):
+    def __parse_contents(self,
+                         jingle: nbxmpp.Node
+                         ) -> tuple[
+                             list[JingleContent],
+                             list[tuple[str, str]],
+                             Optional[str]]:
         # TODO: Needs some reworking
-        contents = []
-        contents_rejected = []
-        reasons = set()
+        contents: list[JingleContent] = []
+        contents_rejected: list[tuple[str, str]] = []
+        reasons: set[str] = set()
         for element in jingle.iterTags('content'):
             transport = get_jingle_transport(element.getTag('transport'))
             if transport:
@@ -706,7 +802,8 @@ class JingleSession:
                     if transport:
                         content = content_type(self, transport=transport)
                         self.add_content(element['name'],
-                                         content, 'peer')
+                                         content,
+                                         'peer')
                         contents.append(content)
                     else:
                         reasons.add('unsupported-transports')
@@ -725,14 +822,18 @@ class JingleSession:
                 break
         return (contents, contents_rejected, failure_reason)
 
-    def __dispatch_error(self, error=None, text=None, type_=None):
+    def __dispatch_error(self,
+                         error: Optional[str] = None,
+                         text: Optional[str] = None,
+                         type_: Optional[str] = None
+                         ) -> None:
         if text:
             text = '%s (%s)' % (error, text)
         if type_ != 'modify':
             self._raise_event('jingle-error-received', reason=text or error)
 
     @staticmethod
-    def __reason_from_stanza(stanza):
+    def __reason_from_stanza(stanza: nbxmpp.Node) -> tuple[str, str]:
         # TODO: Move to GUI?
         reason = 'success'
         reasons = [
@@ -752,13 +853,16 @@ class JingleSession:
                     break
         return (reason, text)
 
-    def __make_jingle(self, action, reason=None):
+    def __make_jingle(self,
+                      action: str,
+                      reason: Optional[nbxmpp.Node] = None
+                      ) -> tuple[Iq, nbxmpp.Node]:
         stanza = nbxmpp.Iq(typ='set', to=nbxmpp.JID.from_string(self.peerjid),
                            frm=self.ourjid)
         attrs = {
             'action': action,
             'sid': self.sid,
-            'initiator' : self.initiator
+            'initiator': self.initiator
         }
         jingle = stanza.addChild('jingle', attrs=attrs,
                                  namespace=Namespace.JINGLE)
@@ -766,7 +870,13 @@ class JingleSession:
             jingle.addChild(node=reason)
         return stanza, jingle
 
-    def __send_error(self, stanza, error, jingle_error=None, text=None, type_=None):
+    def __send_error(self,
+                     stanza: nbxmpp.Node,
+                     error: Optional[str],
+                     jingle_error: Optional[str] = None,
+                     text: Optional[str] = None,
+                     type_: Optional[str] = None
+                     ) -> None:
         err_stanza = nbxmpp.Error(stanza, '%s %s' % (Namespace.STANZAS, error))
         err = err_stanza.getTag('error')
         if type_:
@@ -779,7 +889,7 @@ class JingleSession:
         self.__dispatch_error(jingle_error or error, text, type_)
 
     @staticmethod
-    def __append_content(jingle, content):
+    def __append_content(jingle: nbxmpp.Node, content: JingleContent) -> None:
         """
         Append <content/> element to <jingle/> element
         """
@@ -788,7 +898,7 @@ class JingleSession:
                                'creator': content.creator,
                                'senders': content.senders})
 
-    def __append_contents(self, jingle):
+    def __append_contents(self, jingle: nbxmpp.Node) -> None:
         """
         Append all <content/> elements to <jingle/>
         """
@@ -798,7 +908,7 @@ class JingleSession:
             if content.is_ready():
                 self.__append_content(jingle, content)
 
-    def __session_initiate(self):
+    def __session_initiate(self) -> None:
         assert self.state == JingleStates.ENDED
         stanza, jingle = self.__make_jingle('session-initiate')
         self.__append_contents(jingle)
@@ -807,7 +917,7 @@ class JingleSession:
         self.collect_iq_id(stanza.getID())
         self.state = JingleStates.PENDING
 
-    def __session_accept(self):
+    def __session_accept(self) -> None:
         assert self.state == JingleStates.PENDING
         stanza, jingle = self.__make_jingle('session-accept')
         self.__append_contents(jingle)
@@ -816,33 +926,33 @@ class JingleSession:
         self.collect_iq_id(stanza.getID())
         self.state = JingleStates.ACTIVE
 
-    def __session_info(self, payload=None):
+    def __session_info(self, payload: Optional[nbxmpp.Node] = None) -> None:
         assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('session-info')
         if payload:
             jingle.addChild(node=payload)
         self.connection.connection.send(stanza)
 
-    def _JingleFileTransfer__session_info(self, payload):
+    def _JingleFileTransfer__session_info(self, payload: nbxmpp.Node) -> None:
         # For some strange reason when I call
-        # self.session.__session_info(payload) from the jingleFileTransfer object
-        # within a thread, this method gets called instead. Even though, it
-        # isn't being called explicitly.
+        # self.session.__session_info(payload) from the jingleFileTransfer
+        # object within a thread, this method gets called instead. Even though,
+        # it isn't being called explicitly.
         self.__session_info(payload)
 
-    def _session_terminate(self, reason=None):
+    def _session_terminate(self, reason: Optional[nbxmpp.Node] = None) -> None:
         stanza, jingle = self.__make_jingle('session-terminate', reason=reason)
         self.__broadcast_all(stanza, jingle, None, 'session-terminate-sent')
         if self.connection.connection and self.connection.state.is_available:
             self.connection.connection.send(stanza)
         # TODO: Move to GUI?
-        reason, text = self.__reason_from_stanza(jingle)
+        reason_text, text = self.__reason_from_stanza(jingle)
         if reason not in ('success', 'cancel', 'decline'):
-            self.__dispatch_error(reason, text)
+            self.__dispatch_error(reason_text, text)
         if text:
-            text = '%s (%s)' % (reason, text)
+            text = f'{reason_text} ({text})'
         else:
-            text = reason
+            text = reason_text
         self.connection.get_module('Jingle').delete_jingle_session(self.sid)
         self._raise_event('jingle-disconnected-received',
                           media=None,
@@ -876,7 +986,10 @@ class JingleSession:
                           media=content.media,
                           reason='rejected')
 
-    def __content_remove(self, content, reason=None):
+    def __content_remove(self,
+                         content: JingleContent,
+                         reason: Optional[nbxmpp.Node] = None
+                         ) -> None:
         assert self.state != JingleStates.ENDED
         if self.connection.connection and self.connection.state.is_available:
             stanza, jingle = self.__make_jingle('content-remove', reason=reason)
@@ -887,10 +1000,10 @@ class JingleSession:
                           media=content.media,
                           reason='removed')
 
-    def content_negotiated(self, media):
+    def content_negotiated(self, media: str) -> None:
         self._raise_event('jingle-connected-received', media=media)
 
-    def __transport_accept(self, transport):
+    def __transport_accept(self, transport: JingleTransport) -> None:
         assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('transport-accept')
         self.__append_contents(jingle)
@@ -899,7 +1012,7 @@ class JingleSession:
         self.collect_iq_id(stanza.getID())
         self.state = JingleStates.ACTIVE
 
-    def _raise_event(self, name: str, **kwargs):
+    def _raise_event(self, name: str, **kwargs: Any) -> None:
         jid, resource = app.get_room_and_nick_from_fjid(
             str(self.peerjid))
         jid = JID.from_string(jid)
