@@ -33,6 +33,7 @@ from gajim.common.helpers import load_file_async
 from gajim.common.helpers import write_file_async
 from gajim.common.helpers import get_tls_error_phrase
 from gajim.common.helpers import get_account_proxy
+from gajim.common.i18n import _
 from gajim.common.preview_helpers import aes_decrypt
 from gajim.common.preview_helpers import filename_from_uri
 from gajim.common.preview_helpers import parse_fragment
@@ -78,6 +79,8 @@ class Preview:
         self.file_size: int = 0
         self._received_size: int = 0
 
+        self.info_message: Optional[str] = None
+
         self._soup_message: Optional[Soup.Message] = None
 
         self.key: Optional[bytes] = None
@@ -147,10 +150,14 @@ class Preview:
     def create_thumbnail(self, data: bytes) -> bool:
         self.thumbnail = create_thumbnail(data, self.size)
         if self.thumbnail is None:
+            self.info_message = _('Creating thumbnail failed')
             log.warning('Creating thumbnail failed for: %s', self.orig_path)
             return False
         return True
 
+    def reset_received_size(self) -> None:
+        self._received_size = 0
+
     def update_widget(self, data: Optional[GdkPixbufType] = None) -> None:
         self._widget.update(self, data)
 
@@ -247,7 +254,11 @@ class PreviewManager:
             return False
 
         uri = text
-        urlparts = urlparse(uri)
+        try:
+            urlparts = urlparse(uri)
+        except Exception:
+            return False
+
         if not self._accept_uri(urlparts, uri, additional_data):
             return False
 
@@ -332,8 +343,7 @@ class PreviewManager:
                                  preview.thumbnail,
                                  self._on_thumb_write_finished,
                                  preview)
-        else:
-            preview.update_widget()
+        preview.update_widget()
 
     @staticmethod
     def _on_thumb_load_finished(data: Optional[bytes],
@@ -395,7 +405,8 @@ class PreviewManager:
             log.warning('TLS verification failed: %s', phrase)
             session = self._get_session(preview.account)
             session.cancel_message(message, Soup.Status.CANCELLED)
-            return
+            preview.info_message = _('TLS verification failed: %s') % phrase
+            preview.update_widget()
 
     def _on_content_sniffed(self,
                             message: Soup.Message,
@@ -415,7 +426,7 @@ class PreviewManager:
             return
 
         if file_size == 0:
-            log.info('File size is unknown (zero) for URL: \'%s\'',  uri)
+            log.info('File size is unknown (zero) for URL: \'%s\'', uri)
             session.cancel_message(message, Soup.Status.CANCELLED)
             return
 
@@ -423,8 +434,12 @@ class PreviewManager:
             log.info(
                 'File size (%s) too big for URL: \'%s\'',
                 file_size, uri)
-            if not force:
+            if force:
+                preview.info_message = None
+            else:
                 session.cancel_message(message, Soup.Status.CANCELLED)
+                preview.info_message = _('Automatic preview disabled '
+                                         '(file too big)')
 
         preview.update_widget()
 
@@ -441,10 +456,17 @@ class PreviewManager:
                      preview: Preview) -> None:
         if message.status_code != Soup.Status.OK:
             log.warning('Download failed: %s', preview.request_uri)
-            log.warning(Soup.Status.get_phrase(message.status_code))
+            status_code = Soup.Status.get_phrase(message.status_code)
+            log.warning(status_code)
+            preview.reset_received_size()
+            if message.status_code != 1:
+                # status_code 1: 'Cancelled'
+                preview.info_message = _('Download failed (%s)') % status_code
             preview.update_widget()
             return
 
+        preview.info_message = None
+
         data = message.props.response_body_data.get_data()
         if data is None:
             return
@@ -468,6 +490,8 @@ class PreviewManager:
                                  preview.thumbnail,
                                  self._on_thumb_write_finished,
                                  preview)
+            else:
+                preview.update_widget()
 
     @staticmethod
     def _on_orig_write_finished(_result: bool,
