@@ -1,37 +1,36 @@
-# -*- coding:utf-8 -*-
-## src/common/proxy65_manager.py
-##
-## Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
-##                    Jean-Marie Traissard <jim AT lapin.org>
-## Copyright (C) 2007-2017 Yann Leboulanger <asterix AT lagaule.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
+#                    Jean-Marie Traissard <jim AT lapin.org>
+# Copyright (C) 2007-2014 Yann Leboulanger <asterix AT lagaule.org>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 import socket
 import struct
 import errno
 import logging
-log = logging.getLogger('gajim.c.proxy65_manager')
 
 import nbxmpp
-from common import gajim
-from common import helpers
-from socks5 import Socks5
+from nbxmpp.namespaces import Namespace
 from nbxmpp.idlequeue import IdleObject
-from common.file_props import FilesProp
+
+from gajim.common import app
+from gajim.common import helpers
+from gajim.common.socks5 import Socks5
+from gajim.common.file_props import FilesProp
+
+log = logging.getLogger('gajim.c.proxy65_manager')
 
 S_INITIAL = 0
 S_STARTED = 1
@@ -41,11 +40,12 @@ S_FINISHED = 4
 
 CONNECT_TIMEOUT = 20
 
+
 class Proxy65Manager:
     """
     Keep records for file transfer proxies. Each time account establishes a
     connection to its server call proxy65manger.resolve(proxy) for every proxy
-    that is convigured within the account. The class takes care to resolve and
+    that is configured within the account. The class takes care to resolve and
     test each proxy only once
     """
 
@@ -57,7 +57,7 @@ class Proxy65Manager:
         self.default_proxies = {}
 
     def resolve(self, proxy, connection, sender_jid, default=None,
-    testit=True):
+                testit=True):
         """
         Start
         if testit=False, Gajim won't try to resolve it
@@ -65,7 +65,7 @@ class Proxy65Manager:
         if proxy in self.proxies:
             resolver = self.proxies[proxy]
         else:
-            # proxy is being ressolved for the first time
+            # proxy is being resolved for the first time
             resolver = ProxyResolver(proxy, sender_jid, testit)
             self.proxies[proxy] = resolver
             resolver.add_connection(connection)
@@ -88,7 +88,7 @@ class Proxy65Manager:
                 port = item.getAttr('port')
                 try:
                     port = int(port)
-                except ValueError, TypeError:
+                except (ValueError, TypeError):
                     port = 1080
                 if not host or not jid:
                     self.proxies[proxy]._on_connect_failure()
@@ -114,6 +114,7 @@ class Proxy65Manager:
                 return (resolver.host, resolver.port, resolver.jid)
         return (None, 0, None)
 
+
 class ProxyResolver:
     def resolve_result(self, host, port, jid):
         """
@@ -121,44 +122,46 @@ class ProxyResolver:
         """
         self.host = str(host)
         self.port = int(port)
-        self.jid = unicode(jid)
+        self.jid = str(jid)
         if not self.testit:
             self.state = S_FINISHED
             return
         self.state = S_INITIAL
-        log.info('start resolving %s:%s' % (self.host, self.port))
-        self.receiver_tester = ReceiverTester(self.host, self.port, self.jid,
-                self.sid, self.sender_jid, self._on_receiver_success,
-                self._on_connect_failure)
+        log.info('start resolving %s:%s', self.host, self.port)
+        self.receiver_tester = ReceiverTester(
+            self.host, self.port, self.jid,
+            self.sid, self.sender_jid, self._on_receiver_success,
+            self._on_connect_failure)
         self.receiver_tester.connect()
 
     def _on_receiver_success(self):
-        log.debug('Receiver successfully connected %s:%s' % (self.host,
-                self.port))
-        self.host_tester = HostTester(self.host, self.port, self.jid,
-                self.sid, self.sender_jid, self._on_connect_success,
-                self._on_connect_failure)
+        log.debug('Receiver successfully connected %s:%s',
+                  self.host, self.port)
+        self.host_tester = HostTester(
+            self.host, self.port, self.jid,
+            self.sid, self.sender_jid, self._on_connect_success,
+            self._on_connect_failure)
         self.host_tester.connect()
 
     def _on_connect_success(self):
-        log.debug('Host successfully connected %s:%s' % (self.host, self.port))
+        log.debug('Host successfully connected %s:%s', self.host, self.port)
         iq = nbxmpp.Protocol(name='iq', to=self.jid, typ='set')
         query = iq.setTag('query')
-        query.setNamespace(nbxmpp.NS_BYTESTREAM)
-        query.setAttr('sid',  self.sid)
+        query.setNamespace(Namespace.BYTESTREAM)
+        query.setAttr('sid', self.sid)
 
         activate = query.setTag('activate')
         activate.setData('test@gajim.org/test2')
 
         if self.active_connection:
-            log.debug('Activating bytestream on %s:%s' % (self.host, self.port))
-            self.active_connection.SendAndCallForResponse(iq,
-                     self._result_received)
+            log.debug('Activating bytestream on %s:%s', self.host, self.port)
+            self.active_connection.SendAndCallForResponse(
+                iq, self._result_received)
             self.state = S_ACTIVATED
         else:
             self.state = S_INITIAL
 
-    def _result_received(self, data):
+    def _result_received(self, _nbxmpp_client, data):
         self.disconnect(self.active_connection)
         if data.getType() == 'result':
             self.keep_conf()
@@ -166,11 +169,11 @@ class ProxyResolver:
             self._on_connect_failure()
 
     def keep_conf(self):
-        log.debug('Bytestream activated %s:%s' % (self.host, self.port))
+        log.debug('Bytestream activated %s:%s', self.host, self.port)
         self.state = S_FINISHED
 
     def _on_connect_failure(self):
-        log.debug('Connection failed with %s:%s' % (self.host, self.port))
+        log.debug('Connection failed with %s:%s', self.host, self.port)
         self.state = S_FINISHED
         self.host = None
         self.port = 0
@@ -219,7 +222,7 @@ class ProxyResolver:
         self.active_connection = connection
         iq = nbxmpp.Protocol(name='iq', to=self.proxy, typ='get')
         query = iq.setTag('query')
-        query.setNamespace(nbxmpp.NS_BYTESTREAM)
+        query.setNamespace(Namespace.BYTESTREAM)
         connection.send(iq)
 
     def __init__(self, proxy, sender_jid, testit):
@@ -235,21 +238,30 @@ class ProxyResolver:
         self.jid = None
         self.host = None
         self.port = None
-        self.sid = helpers.get_random_string_16()
+        self.sid = helpers.get_random_string()
         self.sender_jid = sender_jid
         self.testit = testit
 
+
 class HostTester(Socks5, IdleObject):
     """
     Fake proxy tester
     """
 
-    def __init__(self, host, port, jid, sid, sender_jid, on_success, on_failure):
+    def __init__(self,
+                 host,
+                 port,
+                 jid,
+                 sid,
+                 sender_jid,
+                 on_success,
+                 on_failure):
         """
         Try to establish and auth to proxy at (host, port)
 
         Calls on_success, or on_failure according to the result.
         """
+        IdleObject.__init__(self)
         self.host = host
         self.port = port
         self.jid = jid
@@ -260,7 +272,7 @@ class HostTester(Socks5, IdleObject):
         self.file_props.is_a_proxy = True
         self.file_props.proxy_sender = sender_jid
         self.file_props.proxy_receiver = 'test@gajim.org/test2'
-        Socks5.__init__(self, gajim.idlequeue, host, port, None, None, None)
+        Socks5.__init__(self, app.idlequeue, host, port, None, None, None)
         self.sid = sid
 
     def connect(self):
@@ -273,8 +285,8 @@ class HostTester(Socks5, IdleObject):
         self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self._sock.setblocking(False)
         self.fd = self._sock.fileno()
-        self.state = 0 # about to be connected
-        gajim.idlequeue.plug_idle(self, True, False)
+        self.state = 0  # about to be connected
+        app.idlequeue.plug_idle(self, True, False)
         self.do_connect()
         self.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
         return None
@@ -292,15 +304,15 @@ class HostTester(Socks5, IdleObject):
         if self.state == 0:
             self.do_connect()
             return
-        elif self.state == 1: # send initially: version and auth types
+        if self.state == 1:  # send initially: version and auth types
             data = self._get_auth_buff()
             self.send_raw(data)
         else:
             return
         self.state += 1
         # unplug and plug for reading
-        gajim.idlequeue.plug_idle(self, False, True)
-        gajim.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
+        app.idlequeue.plug_idle(self, False, True)
+        app.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
 
     def pollin(self):
         self.idlequeue.remove_timeout(self.fd)
@@ -308,7 +320,7 @@ class HostTester(Socks5, IdleObject):
             self.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
             # begin negotiation. on success 'address' != 0
             buff = self.receive()
-            if buff == '':
+            if buff == b'':
                 # end connection
                 self.pollend()
                 return
@@ -322,9 +334,9 @@ class HostTester(Socks5, IdleObject):
             data = self._get_request_buff(self._get_sha1_auth())
             self.send_raw(data)
             self.state += 1
-            log.debug('Host authenticating to %s:%s' % (self.host, self.port))
+            log.debug('Host authenticating to %s:%s', self.host, self.port)
         elif self.state == 3:
-            log.debug('Host authenticated to %s:%s' % (self.host, self.port))
+            log.debug('Host authenticated to %s:%s', self.host, self.port)
             self.on_success()
             self.disconnect()
             self.state += 1
@@ -335,11 +347,11 @@ class HostTester(Socks5, IdleObject):
         try:
             self._sock.connect((self.host, self.port))
             self._sock.setblocking(False)
-            log.debug('Host Connecting to %s:%s' % (self.host, self.port))
+            log.debug('Host Connecting to %s:%s', self.host, self.port)
             self._send = self._sock.send
             self._recv = self._sock.recv
-        except Exception, ee:
-            errnum = ee[0]
+        except Exception as ee:
+            errnum = ee.errno
             # 56 is for freebsd
             if errnum in (errno.EINPROGRESS, errno.EALREADY, errno.EWOULDBLOCK):
                 # still trying to connect
@@ -353,23 +365,32 @@ class HostTester(Socks5, IdleObject):
             self._sock.setblocking(False)
             self._send = self._sock.send
             self._recv = self._sock.recv
-        self.buff = ''
-        self.state = 1 # connected
-        log.debug('Host connected to %s:%s' % (self.host, self.port))
+        self.buff = b''
+        self.state = 1  # connected
+        log.debug('Host connected to %s:%s', self.host, self.port)
         self.idlequeue.plug_idle(self, True, False)
         return
 
+
 class ReceiverTester(Socks5, IdleObject):
     """
     Fake proxy tester
     """
 
-    def __init__(self, host, port, jid, sid, sender_jid, on_success, on_failure):
+    def __init__(self,
+                 host,
+                 port,
+                 jid,
+                 sid,
+                 sender_jid,
+                 on_success,
+                 on_failure):
         """
         Try to establish and auth to proxy at (host, port)
 
         Call on_success, or on_failure according to the result.
         """
+        IdleObject.__init__(self)
         self.host = host
         self.port = port
         self.jid = jid
@@ -380,7 +401,7 @@ class ReceiverTester(Socks5, IdleObject):
         self.file_props.is_a_proxy = True
         self.file_props.proxy_sender = sender_jid
         self.file_props.proxy_receiver = 'test@gajim.org/test2'
-        Socks5.__init__(self, gajim.idlequeue, host, port, None, None, None)
+        Socks5.__init__(self, app.idlequeue, host, port, None, None, None)
         self.sid = sid
 
     def connect(self):
@@ -393,8 +414,8 @@ class ReceiverTester(Socks5, IdleObject):
         self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self._sock.setblocking(False)
         self.fd = self._sock.fileno()
-        self.state = 0 # about to be connected
-        gajim.idlequeue.plug_idle(self, True, False)
+        self.state = 0  # about to be connected
+        app.idlequeue.plug_idle(self, True, False)
         self.do_connect()
         self.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
         return None
@@ -412,15 +433,15 @@ class ReceiverTester(Socks5, IdleObject):
         if self.state == 0:
             self.do_connect()
             return
-        elif self.state == 1: # send initially: version and auth types
+        if self.state == 1:  # send initially: version and auth types
             data = self._get_auth_buff()
             self.send_raw(data)
         else:
             return
         self.state += 1
         # unplug and plug for reading
-        gajim.idlequeue.plug_idle(self, False, True)
-        gajim.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
+        app.idlequeue.plug_idle(self, False, True)
+        app.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
 
     def pollin(self):
         self.idlequeue.remove_timeout(self.fd)
@@ -428,7 +449,7 @@ class ReceiverTester(Socks5, IdleObject):
             self.idlequeue.set_read_timeout(self.fd, CONNECT_TIMEOUT)
             # begin negotiation. on success 'address' != 0
             buff = self.receive()
-            if buff == '':
+            if buff == b'':
                 # end connection
                 self.pollend()
                 return
@@ -440,7 +461,7 @@ class ReceiverTester(Socks5, IdleObject):
             if version != 0x05 or method == 0xff:
                 self.pollend()
                 return
-            log.debug('Receiver authenticating to %s:%s' % (self.host, self.port))
+            log.debug('Receiver authenticating to %s:%s', self.host, self.port)
             data = self._get_request_buff(self._get_sha1_auth())
             self.send_raw(data)
             self.state += 1
@@ -452,7 +473,7 @@ class ReceiverTester(Socks5, IdleObject):
             if version != 0x05 or reply != 0x00:
                 self.pollend()
                 return
-            log.debug('Receiver authenticated to %s:%s' % (self.host, self.port))
+            log.debug('Receiver authenticated to %s:%s', self.host, self.port)
             self.on_success()
             self.disconnect()
             self.state += 1
@@ -463,11 +484,11 @@ class ReceiverTester(Socks5, IdleObject):
         try:
             self._sock.setblocking(False)
             self._sock.connect((self.host, self.port))
-            log.debug('Receiver Connecting to %s:%s' % (self.host, self.port))
+            log.debug('Receiver Connecting to %s:%s', self.host, self.port)
             self._send = self._sock.send
             self._recv = self._sock.recv
-        except Exception, ee:
-            errnum = ee[0]
+        except Exception as ee:
+            errnum = ee.errno
             # 56 is for freebsd
             if errnum in (errno.EINPROGRESS, errno.EALREADY, errno.EWOULDBLOCK):
                 # still trying to connect
@@ -482,6 +503,6 @@ class ReceiverTester(Socks5, IdleObject):
             self._send = self._sock.send
             self._recv = self._sock.recv
         self.buff = ''
-        self.state = 1 # connected
-        log.debug('Receiver connected to %s:%s' % (self.host, self.port))
+        self.state = 1  # connected
+        log.debug('Receiver connected to %s:%s', self.host, self.port)
         self.idlequeue.plug_idle(self, True, False)
