@@ -1083,8 +1083,8 @@ class LoginDialog(SettingsDialog):
                     _('Save Password'),
                     SettingType.ACCOUNT_CONFIG,
                     'savepass',
-                    enabled_func=(lambda: not app.settings.get('use_keyring')
-                                  or passwords.KEYRING_AVAILABLE)),
+                    enabled_func=(lambda: not app.settings.get('use_keyring') or
+                                  passwords.KEYRING_AVAILABLE)),
 
             Setting(SettingKind.CHANGEPASSWORD,
                     _('Change Password'),
