@@ -21,6 +21,7 @@ from typing import Union
 
 import logging
 import time
+import pickle
 
 from gi.repository import Gio
 from gi.repository import Gdk
@@ -107,7 +108,7 @@ class ChatList(Gtk.ListBox, EventHelper):
         return self._workspace_id
 
     def get_unread_count(self) -> int:
-        return sum([chats.unread_count for chats in self._chats.values()])
+        return sum(chats.unread_count for chats in self._chats.values())
 
     def get_chat_unread_count(self,
                               account: str,
@@ -432,7 +433,7 @@ class ChatList(Gtk.ListBox, EventHelper):
             return
 
         if event.correct_id == row.message_id:
-            row.set_message_text(event.msgtxt)
+            row.set_message_text(event.msgtxt, event.nickname)
 
     def _on_message_moderated(self, event: events.MessageModerated) -> None:
         row = self._chats.get((event.account, event.jid))
@@ -595,7 +596,7 @@ class ChatRow(Gtk.ListBoxRow):
 
         if self.contact.is_groupchat and not self.contact.can_notify():
             self._ui.unread_label.get_style_context().add_class(
-               'unread-counter-silent')
+                'unread-counter-silent')
 
         # Get last chat message from archive
         line = app.storage.archive.get_last_conversation_line(account, jid)
@@ -692,6 +693,10 @@ class ChatRow(Gtk.ListBoxRow):
                          ) -> None:
         if event.button == 3:  # right click
             self._popup_menu(event)
+        elif event.button == 2:  # middle click
+            app.window.activate_action(
+                'remove-chat',
+                GLib.Variant('as', [self.account, str(self.jid)]))
 
     def _popup_menu(self, event: Gdk.EventButton):
         menu = get_chat_list_row_menu(
@@ -733,8 +738,8 @@ class ChatRow(Gtk.ListBoxRow):
                           _time: int
                           ) -> None:
         drop_type = Gdk.Atom.intern_static_string('CHAT_LIST_ITEM')
-        data = f'{self.account} {self.jid}'.encode('utf-8')
-        selection_data.set(drop_type, 32, data)
+        byte_data = pickle.dumps((self.account, self.jid))
+        selection_data.set(drop_type, 8, byte_data)
 
     def toggle_pinned(self) -> None:
         self._pinned = not self._pinned
