@@ -89,10 +89,8 @@ from gajim.command_system.implementation.middleware import CommandTools
 # module, but still they need to be kept around. Importing them automatically
 # registers the contained CommandContainers with the command system, thereby
 # populating the list of available commands.
-# pylint: disable=unused-import
-from gajim.command_system.implementation import standard
-from gajim.command_system.implementation import execute
-# pylint: enable=unused-import
+from gajim.command_system.implementation import standard  # noqa: F401
+from gajim.command_system.implementation import execute  # noqa: F401
 
 if app.is_installed('GSPELL'):
     from gi.repository import Gspell  # pylint: disable=ungrouped-imports
@@ -329,7 +327,8 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
         getattr(self, method_name)(event)
 
     def _on_message_updated(self, event: events.MessageUpdated) -> None:
-        self.conversation_view.correct_message(event.correct_id, event.msgtxt)
+        self.conversation_view.correct_message(
+            event.correct_id, event.msgtxt, event.nickname)
 
     def _on_message_moderated(self, event: events.MessageModerated) -> None:
         text = get_retraction_text(
@@ -634,7 +633,8 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
     def on_language_changed(self, checker: Gspell.Checker, _param: Any) -> None:
         gspell_lang = checker.get_language()
         if gspell_lang is not None:
-            self.contact.settings.set('speller_language', gspell_lang.get_code())
+            self.contact.settings.set('speller_language',
+                                      gspell_lang.get_code())
 
     def shutdown(self) -> None:
         # remove_gui_extension_point() is called on shutdown, but also when
@@ -867,41 +867,6 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
 
         message_buffer = self.msg_textview.get_buffer()
         event_state = event.get_state()
-        if event.keyval == Gdk.KEY_Tab:
-            start, end = message_buffer.get_bounds()
-            position = message_buffer.get_insert()
-            end = message_buffer.get_iter_at_mark(position)
-            text = message_buffer.get_text(start, end, False)
-            split = text.split()
-            if (text.startswith(self.COMMAND_PREFIX) and
-                    not text.startswith(self.COMMAND_PREFIX * 2) and
-                    len(split) == 1):
-                text = split[0]
-                bare = text.lstrip(self.COMMAND_PREFIX)
-                if len(text) == 1:
-                    self.command_hits = []
-                    for command in self.list_commands():
-                        for name in command.names:
-                            self.command_hits.append(name)
-                else:
-                    if (self.last_key_tabs and self.command_hits and
-                            self.command_hits[0].startswith(bare)):
-                        self.command_hits.append(self.command_hits.pop(0))
-                    else:
-                        self.command_hits = []
-                        for command in self.list_commands():
-                            for name in command.names:
-                                if name.startswith(bare):
-                                    self.command_hits.append(name)
-
-                if self.command_hits:
-                    message_buffer.delete(start, end)
-                    message_buffer.insert_at_cursor(
-                        self.COMMAND_PREFIX + self.command_hits[0] + ' ')
-                    self.last_key_tabs = True
-                return True
-            if not self.is_groupchat:
-                self.last_key_tabs = False
         if event.keyval == Gdk.KEY_Up:
             if event_state & Gdk.ModifierType.CONTROL_MASK:
                 if event_state & Gdk.ModifierType.SHIFT_MASK:  # Ctrl+Shift+UP
@@ -980,7 +945,7 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
                        _widget: Gtk.Widget,
                        _context: Gdk.DragContext,
                        _time: int
-                        ) -> None:
+                       ) -> None:
         self.xml.drop_area.set_no_show_all(True)
         self.xml.drop_area.hide()
 
