@@ -229,10 +229,6 @@ class MessageRow(BaseRow):
 
         self.show_all()
 
-    def update_text_tags(self) -> None:
-        if isinstance(self._message_widget, MessageWidget):
-            self._message_widget.update_text_tags()
-
     def _check_for_highlight(self, text: str) -> None:
         assert isinstance(self._contact, GroupchatContact)
         if self._contact.nickname is None:
@@ -421,9 +417,9 @@ class MessageRow(BaseRow):
         self._message_widget.add_with_styling(text)
         self.get_style_context().add_class('retracted-message')
 
-    def set_correction(self, text: str) -> None:
+    def set_correction(self, text: str, nickname: Optional[str]) -> None:
         if not isinstance(self._message_widget, PreviewWidget):
-            self._message_widget.add_with_styling(text)
+            self._message_widget.add_with_styling(text, nickname)
 
         self._has_receipt = False
         self._message_icons.set_receipt_icon_visible(False)
