@@ -201,8 +201,6 @@ class ConversationView(Gtk.ListBox):
         self._insert_message(join_left)
 
     def add_user_status(self, name: str, show: str, status: str) -> None:
-        if not self._contact.settings.get('print_status'):
-            return
         user_status = UserStatus(self._account, name, show, status)
         self._insert_message(user_status)
 
@@ -279,8 +277,8 @@ class ConversationView(Gtk.ListBox):
         if kind == 'incoming':
             self._read_marker_row.set_last_incoming_timestamp(
                 message_row.timestamp)
-        if (marker is not None and marker == 'displayed'
-                and message_id is not None):
+        if (marker is not None and marker == 'displayed' and
+                message_id is not None):
             self.set_read_marker(message_id)
 
         self._insert_message(message_row)
@@ -485,19 +483,18 @@ class ConversationView(Gtk.ListBox):
             if isinstance(row, MessageRow):
                 row.update_avatar()
 
-    def update_text_tags(self) -> None:
-        for row in cast(list[BaseRow], self.get_children()):
-            if isinstance(row, MessageRow):
-                row.update_text_tags()
-
     def scroll_to_end(self, force: bool = False) -> None:
         if self.autoscroll or force:
             GLib.idle_add(self.emit, 'scroll-to-end')
 
-    def correct_message(self, correct_id: str, text: str) -> None:
+    def correct_message(self,
+                        correct_id: str,
+                        text: str,
+                        nickname: Optional[str]
+                        ) -> None:
         message_row = self._get_row_by_message_id(correct_id)
         if message_row is not None:
-            message_row.set_correction(text)
+            message_row.set_correction(text, nickname)
             message_row.set_merged(False)
 
     def show_message_retraction(self, stanza_id: str, text: str) -> None:
