@@ -428,12 +428,16 @@ def get_chat_list_row_menu(workspace_id: str,
     toggle_label = _('Unpin Chat') if pinned else _('Pin Chat')
     menu.add_item(toggle_label, 'win.toggle-chat-pinned', params)
 
+    submenu = menu.add_submenu(_('Move Chat'))
     workspaces = app.settings.get_workspaces()
     if len(workspaces) > 1:
-        submenu = menu.add_submenu(_('Move Chat'))
         for name, params in get_workspace_params(workspace_id, account, jid):
             submenu.add_item(name, 'win.move-chat-to-workspace', params)
 
+    params = AccountJidParam(account=account, jid=jid)
+    submenu.add_item(
+        _('New Workspace'), 'win.move-chat-to-new-workspace', params)
+
     if can_add_to_roster(contact):
         params = AccountJidParam(account=account, jid=jid)
         menu.add_item(_('Add to Contact List…'), 'win.add-to-roster', params)
@@ -549,18 +553,26 @@ def get_groupchat_roster_menu(account: str,
     return menu
 
 
-class SearchMenu(Gtk.Menu):
-    def __init__(self, treeview: Gtk.TreeView) -> None:
-        Gtk.Menu.__init__(self)
-        self._copy_item = Gtk.MenuItem(label=_('Copy'))
-        self._copy_item.set_action_name('app.copy-text')
-        self.set_copy_text('')
-        self._copy_item.show()
-        self.append(self._copy_item)
-        self.attach_to_widget(treeview, None)
+def get_component_search_menu(jid: Optional[str], copy_text: str) -> Gio.Menu:
+    menu_items: list[tuple[str, str]] = [
+        ('app.copy-text', _('Copy')),
+    ]
+    if jid is not None:
+        menu_items.append(
+            ('app.start-chat', _('Start Chat…')))
 
-    def set_copy_text(self, text: str) -> None:
-        self._copy_item.set_action_target_value(GLib.Variant('s', text))
+    menu = Gio.Menu()
+    for item in menu_items:
+        action, label = item
+        menuitem = Gio.MenuItem.new(label, action)
+        if action == 'app.copy-text':
+            data = copy_text
+        else:
+            data = jid
+        variant = GLib.Variant('s', data)
+        menuitem.set_action_and_target_value(action, variant)
+        menu.append_item(menuitem)
+    return menu
 
 
 def escape_mnemonic(label: Optional[str]) -> Optional[str]:
